// Created on: 2012-03-23
// Created by: DBV
// Copyright (c) 2002-2014 OPEN CASCADE SAS
//
// This file is part of Open CASCADE Technology software library.
//
// This library is free software; you can redistribute it and/or modify it under
// the terms of the GNU Lesser General Public License version 2.1 as published
// by the Free Software Foundation, with special exception defined in the file
// OCCT_LGPL_EXCEPTION.txt. Consult the file LICENSE_LGPL_21.txt included in OCCT
// distribution for complete text of the license and disclaimer of any warranty.
//
// Alternatively, this file may be used under the terms of Open CASCADE
// commercial license or contractual agreement.

#include <QABugs.hxx>

void QABugs::Commands(Draw_Interpretor& theCommands)
{
  QABugs::Commands_1(theCommands);
  QABugs::Commands_2(theCommands);
  QABugs::Commands_3(theCommands);
  QABugs::Commands_5(theCommands);
  QABugs::Commands_6(theCommands);
  QABugs::Commands_7(theCommands);
  QABugs::Commands_8(theCommands);
  QABugs::Commands_9(theCommands);
  QABugs::Commands_10(theCommands);
  QABugs::Commands_11(theCommands);
  QABugs::Commands_12(theCommands);
  QABugs::Commands_13(theCommands);
  QABugs::Commands_14(theCommands);
  QABugs::Commands_15(theCommands);
  QABugs::Commands_16(theCommands);
  QABugs::Commands_17(theCommands);
  QABugs::Commands_18(theCommands);
  QABugs::Commands_19(theCommands);
  QABugs::Commands_20(theCommands);
  QABugs::Commands_BVH(theCommands);

  return;
}
